OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "הכרזות Nextcloud",
    "Nextcloud announcement" : "הכרזת Nextcloud",
    "Read more" : "מידע נוסף",
    "Disable announcements" : "השבתת הכרזות",
    "(These announcements are only shown to administrators)" : "(ההכרזות האלו מופיעות למנהלים בלבד)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "הכרזות Nextcloud מביאות את החדשות העדכניות ביותר של Nextcloud להתראות שלך"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
